#
# spec file for package ykpers
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ykpers
Version:        1.20.0
Release:        3.11
Summary:        Reference implementation for configuration of YubiKeys
License:        BSD-2-Clause
Group:          Productivity/Networking/Security
URL:            https://developers.yubico.com/yubikey-personalization/
Source0:        https://developers.yubico.com/yubikey-personalization/Releases/ykpers-%{version}.tar.gz
Source1:        https://developers.yubico.com/yubikey-personalization/Releases/ykpers-%{version}.tar.gz.sig
Source2:        %{name}.keyring
# PATCH-FIX-UPSTREAM ykpers-json.patch gh#Yubico/yubikey-personalization#159
Patch0:         ykpers-json.patch
BuildRequires:  libyubikey-devel >= 1.12
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(json-c) >= 0.10
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)
Provides:       yubikey-personalization = %{version}

%description
Yubico's YubiKey can be re-programmed. This project provides a reference implementation for configuration of YubiKeys.

%package    -n libykpers-1-1
Summary:        Reference implementation for configuration of YubiKeys
Group:          System/Libraries

%description -n libykpers-1-1
Yubico's YubiKey can be re-programmed. This project provides a reference implementation for configuration of YubiKeys.

%package -n libykpers-devel
Summary:        Development files for the ykpers library
Group:          Development/Languages/C and C++
Requires:       glibc-devel
Requires:       libykpers-1-1 = %{version}

%description -n libykpers-devel
Yubico's YubiKey can be re-programmed. This project provides a reference implementation for configuration of YubiKeys.

%prep
%autosetup
# Add access for group "users"
sed -i 's|--device=$env{DEVNAME}"|--device=$env{DEVNAME}" GROUP="users"|g' 70-yubikey.rules
# PATCH-FIX-UPSTREAM gh#Yubico/yubikey-personalization#155 -- Fix build with gcc 10
sed -i 's|^const char|extern const char|g' ykpers-args.h

%build
%configure --disable-static \
    --with-udevrulesdir=%{_udevrulesdir} \
    --with-backend=libusb-1.0 --without-libusb-prefix
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
%make_build V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post
%{?udev_rules_update:%udev_rules_update}

%post -n libykpers-1-1 -p /sbin/ldconfig
%postun -n libykpers-1-1 -p /sbin/ldconfig

%files
%doc ChangeLog README
%license COPYING
%{_bindir}/*
%{_mandir}/man?/*
%{_udevrulesdir}/*-yubikey.rules

%files -n libykpers-1-1
%{_libdir}/libykpers-1.so.*

%files -n libykpers-devel
%dir %{_includedir}/ykpers-1
%{_includedir}/ykpers-1/*.h
%{_libdir}/pkgconfig/ykpers-1.pc
%{_libdir}/libykpers-1.so

%changelog
* Mon Jun  7 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static)
* Mon Jun  8 2020 Torsten Gruner <t.gruner@katodev.de>
- Fix build with gcc 10 [gh#Yubico/yubikey-personalization#155]
- Fix boolean value with json-c 0.14 [gh#Yubico/yubikey-personalization#159]
  adds ykpers-json.patch
* Sun Jul 14 2019 Karol Babioch <kbabioch@suse.com>
- Version 1.20.0 (released 2019-07-03d)
  - Add yk_open_key_vid_pid() allowing vid and pid to be specified.
  - Documentation fixes.
  - Clear potentially sensitive material from buffers.
  - Fix potential buffer overwrite.
- Applied spec-cleaner
* Fri Feb 22 2019 Karol Babioch <kbabioch@suse.de>
- Version 1.19.3 (released 2019-02-22)
  - Fix capability read.
* Tue Feb 19 2019 Karol Babioch <kbabioch@suse.de>
- Version 1.19.2 (released 2019-02-19)
  - Fix test on mac.
  - Fix serial read and challenge response.
* Tue Feb 19 2019 Karol Babioch <kbabioch@suse.de>
- Version 1.19.1 (released 2019-02-19)
  - Error out on json output with randomSeed.
  - Validate more length fields.
  - Use correct FormatMessage function on windows.
  - Overflow, bounds and error condition checks.
  - Try to zero sensitive memory better.
* Fri Sep 28 2018 Jan Engelhardt <jengelh@inai.de>
- Fix RPM groups.
- Use noun phrase in summary.
* Thu Sep 27 2018 Karol Babioch <kbabioch@suse.com>
- Version 1.19.0 (released 2018-04-24)
  - Add yk_write_device_info().
  - Add ykpersonalize cli switch -D for device info.
  - Add code for handling personalization interface of major version 5.
* Sun Apr  8 2018 wr@rosenauer.org
- updated to 1.18.1 (released 2018-01-16)
  - Support reading accesscode and private ID from stdin.
  - Parse optional arguments correctly.
  - Documentation fixes.
  - Fix for ykinfo modhex serial output when it ends with c.
  - Treat all firmware versions as supported.
* Wed Apr 19 2017 meissner@suse.com
- updated to 1.18.0 (released 2017-01-27)
  - Let ykchalresp read challenge from a file.
  - Add support of working with a numbered key when many connected Thanks to Thomas Habets <habets@google.com>
  - Documentation clarifications.
  - Fixup argument parsing of flags with optional arguments on BSD platforms.
  - Fix a file descriptor leak on windows.
* Thu Jan  7 2016 t.gruner@katodev.de
- Version 1.17.3 (released 2015-12-28)
  - Dont read to much if we don’t find a key.
  - Text updates to make options clearer.
  - Correct logic for question when mode switching to non-otp mode.
  - Add 4.3 as supported firmware.
* Tue Sep 29 2015 t.gruner@katodev.de
- Version 1.17.2 (released 2015-09-22)
  - Let _yk_write() return an error if yk_wait_for_key_status() fails.
  - Fix a mistake in help, fixed is up to 16 bytes, 32 characters.
  - Add 4.2 as supported firmware.
* Tue May  5 2015 crrodriguez@opensuse.org
- Remove all duplicated/unnecesary buildRequires
- Use %%{_udevrulesdir}
- Enable verbose build
- Run udev_rules_update if defined in %%post.
- Update to version 1.17.1
  * add yk_get_capabilities() to fetch capabilities.
  * add -c to ykinfo to fetch capabilities.
  * whitelist firmware 4.1.x
- fixed urls
- .sig and ykpers.keyring added
* Wed Apr  1 2015 t.gruner@katodev.de
- Version 1.17.1 (released 2015-04-01)
  - Fixup of 1.17.0
- Version 1.17.0 (released 2015-04-01)
  - add yk_get_capabilities() to fetch capabilities.
  - add -c to ykinfo to fetch capabilities.
  - whitelist firmware 4.1.x
* Thu Mar 26 2015 t.gruner@katodev.de
- Version 1.16.4 (released 2015-03-23)
  - change the tool to accept autoeject time as a short instead of a byte
* Mon Mar 16 2015 t.gruner@katodev.de
- Version 1.16.3 (released 2015-03-10)
  - whitelist YubiKey version 3.4.x
  - only try to set libusb configuration if it’s unset on the device
* Tue Dec 23 2014 Greg.Freemyer@gmail.com
- merge subproject -doc into main package.  It was not big enough to justify.
- use pkgconfig(json-c) >= 0.10 instead of BuildRequires: libjson-devel >= 0.10
* Tue Dec  9 2014 t.gruner@katodev.de
- Version 1.16.2 (released 2014-11-28)
  - ykinfo: fix modhex printout when serial is an odd number of hex digits.
  - whitelist yubikey version 4.0.x
  - try to open more PIDs and add for udev.
* Wed Nov  5 2014 t.gruner@katodev.de
- Patch: Add group "user" to udev-rule
- Use libusb-1.0
- Version 1.16.1 (released 2014-10-30)
  - Fix udev rules so they contain four digits.
  - Only try to detach the kernel driver if it's attached.
    For libusb-1.0
  - Let import config report errors properly.
* Fri Oct  3 2014 mmarek@suse.cz
- Update to version 1.16.0
  - lots bug and warning fixes
  - support for firmware version 2.3
  - new command ykinfo to show information about YubiKey
  - ykpersonalize -z to zap configuration on YubiKey
  - ykpersonalize -d for dry-run
  - let no -a given mean generate a random key
  - let -a without option mean ask for raw key on STDIN
* Mon Apr 18 2011 crrodriguez@opensuse.org
- Update to version 1.5
* Tue Feb  8 2011 cristian.rodriguez@opensuse.org
- Fix package, should be version 1.4.x not 1.3.x
* Fri Jan 28 2011 cristian.rodriguez@opensuse.org
- Initial version
